@@ -680,7 +680,7 @@ function getServices(callback) {
             var cfg = configGetKey("modules")[pluginName].other;
             var lang = configGetKey("language");
             for (var j in cfg) {
-                services[i + Number(j)] = cfg[j][lang] || cfg[j].en_US;
+                services.push(cfg[j][lang] || cfg[j].en_US);
             }
         }));
     lock();
